# Majority Judgment

## Common language

The Majority Judgment asks us to judge each choice in an absolute way
(i.e. such that the removal or addition of choices
does not change our evaluation of the other choices)
by giving them a grade (or level) on a common scale.

This common scale contains as many grades as our supposed common expertise
is able to distinguish, in order to faithfully represent
the properties of the attribute it tries to measure.
Hence, a common scale should be crafted for each different attribute.
The inter-subjective meaning of each grade
being reinforced by the practice of judgments.

### Examples

Examples of common scales could be:
- [“No”, “No, but”, “Yes, but”, “Yes”] for adhesion,
- [“None”, “Not Enough”, “Enough”, “Much”, “Too Much”] for quantity,
- [“To Do”, “Prioritized”, “Blocking”, “Urgent”, “Too Urgent”] for priority,
- [“Useless”, “Interesting”, “Useful”, “Indispensable”, “Enslaving”] for utility,
- [“To Reject”, “Insufficient”, “Acceptable”, “Good”, “Very Good”, “Too Good”] for quality.

## Judging one choice

For each choice taken separately,
the initial common scale (whose grades are all of equal length 1)
is dilated such that the length of each grade is multiplied
by the number of individual judgments of this grade obtained by this choice.
Like this, the only level which is defended by an absolute majority
begining from one side of the scale,
without being rejected by an absolute majority
beginning from the other side of the scale,
is the one which spans over the middle of this dilated scale.
This is the most consensual majority grade for this choice.

If the number of individual judgments is small and even,
there is however a probability that two different grades
border the middle of this dilated scale,
but only the lower grade rewards consensus,
and thus is considered to be the most consensual.
Indeed, if any other choice obtains less scattered judgments
all enclosed to this two grades,
it will obtain a most consensual majoritary grade
greater or egal to the one of this choice.
Which would not necessarily be the case with the greater grade.

## Ranking many choices

To sort many choices means being able to compare them two-by-two,
which is done according to their most consensual majority grade.
In case of equality, the minimum individual judgments of this grade
are removed from both dilated scales so that one of them has no longer any,
then the comparison goes on with the new most consensual majority grades.
Like this, either a choice is judged higher than the other,
by the geatest number of judgments which differenciate them according
to a most consensual majoritary grade,
or both choices precisely have the same distribution of individual judgments.

One can see that the farest an individual judgment is
from the most consensual majoritary grade,
the less impact it has on the result.
This rewards honest individual judgments,
by ignoring as near as may be the most cranky or strategic judgements.

## Properties

The Majority Judgment is:

- allowing anonymity:
  interchanging the names of judges does not change the outcome:
  all judges are given an equal power.

- neutral:
  interchanging the names of choices does not change the outcome:
  all choices are treated equally.

- complete:
  every choice is either superior or inferior
  to any other choice, or both when equal.
  Hence the Majority Judgement is not subject
  to Condorcet's paradox.

- monotone:
  if a choice is superior or egal to another one,
  and a judge increases its grade for it,
  it becomes strictly superior.

- transitive:
  if a first choice is superior to a second one,
  and this second one is superior to a third,
  then the first is superior to the third).

- coherent:
  it is independent of irrelevant alternatives as formulated by Nash-Chernoff:
  removal or addition of choices does not change
  the judges’ evaluations of the other choices.
  Hence the Majority Judgement is not subject
  to Arrow's paradox.

- strategy-proof-in-grading:
  judging a choice higher or lower
  than our intimate judgement has the opposite impact
  on its most consensual majority grade.

- partially strategy-proof-in-ranking:
  increasing (resp. decreasing) the rank of a choice with respect to another choice,
  can not decrease (resp. increase) the rank of this other choice.

- not Condorcet-consistent except when the electorate is “polarized”
  (when the higher (resp. the lower) a judge evaluates one choice the lower (resp. the higher)
  she/he evaluates the other, so there can be no consensus)
  hence when judges are most tempted to manipulate.

- not excluding the no-show paradox (when it is better for a judge not to judge
  than to express her/his opinion sincerely because her/his vote
  can tip the scales against his favorite choice).
  
  This property is judged insignificant, by Michel Balinski and Rida Laraki,
  when compared with the serious problems of methods of election,
  the Arrow and Condorcet paradoxes and strategic manipulation.
